@@ -11,7 +11,8 @@ class BaseDataset(Dataset):
     LBL_COL = 'label'
 
     def __init__(self,
-                 transform=None):
+                 transform=None,
+                 val_transform=None):
         """
         Initializes the dataset.
 
@@ -22,7 +23,9 @@ class BaseDataset(Dataset):
         transform : Union[callable, optional]
             Optional transform to be applied to the images.
         """
+        self.training = True
         self.transform = transform
+        self.val_transform = val_transform
         self.labelencoder = sklearn.preprocessing.LabelEncoder()
 
     def save_label_encoder(self, path: str):
