@@ -7,7 +7,7 @@ from torch.utils.data import DataLoader
 def get_train_validation_data_loaders(ds: Dataset,
                                       batch_size: int,
                                       num_workers: int,
-                                      val_size: int):
+                                      val_size: float):
     # obtain training indices that will be used for validation
     num_train = len(ds)
     indices = list(range(num_train))
